@@ -7,6 +7,23 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class LibSvmSourceBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.source.LibSvmSourceBatchOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(LibSvmSourceBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setStartIndex(self, val):
+        return self._add_param('startIndex', val)
+
+
 class LinearClassifierModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
     CLS_NAME = 'com.alibaba.alink.operator.common.linear.LinearClassifierModelInfoBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -1136,29 +1153,3 @@ class RandomForestTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
     def setWeightCol(self, val):
         return self._add_param('weightCol', val)
 
-
-class RandomTableSourceBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.source.RandomTableSourceBatchOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomTableSourceBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setNumCols(self, val):
-        return self._add_param('numCols', val)
-
-    def setNumRows(self, val):
-        return self._add_param('numRows', val)
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setOutputColConfs(self, val):
-        return self._add_param('outputColConfs', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
