@@ -7,6 +7,17 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class UnionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.sql.UnionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(UnionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
 class UserCfItemsPerUserRecommBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.recommendation.UserCfItemsPerUserRecommBatchOp'
     OP_TYPE = 'FUNCTION'
