@@ -114,7 +114,7 @@ class GbdtRegressor(Estimator, HasLazyPrintModelInfo):
         return self._add_param('weightCol', val)
 
 
-class GeneralizedLinearRegression(Estimator):
+class GeneralizedLinearRegression(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.GeneralizedLinearRegression'
     OP_TYPE = 'FUNCTION'
 
