@@ -4,113 +4,6 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
-class QuantileDiscretizerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.QuantileDiscretizerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(QuantileDiscretizerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setDropLast(self, val):
-        return self._add_param('dropLast', val)
-
-    def setEncode(self, val):
-        return self._add_param('encode', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class RandomForestPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.RandomForestPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class RandomForestRegPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.RandomForestRegPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestRegPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class RandomTableSourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.RandomTableSourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomTableSourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMaxRows(self, val):
-        return self._add_param('maxRows', val)
-
-    def setNumCols(self, val):
-        return self._add_param('numCols', val)
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setOutputColConfs(self, val):
-        return self._add_param('outputColConfs', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setTimePerSample(self, val):
-        return self._add_param('timePerSample', val)
-
-    def setTimeZones(self, val):
-        return self._add_param('timeZones', val)
-
-
 class RandomVectorSourceStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.source.RandomVectorSourceStreamOp'
     OP_TYPE = 'SOURCE'
@@ -1162,3 +1055,32 @@ class WindowGroupByStreamOp(StreamOperator):
     def setWindowType(self, val):
         return self._add_param('windowType', val)
 
+
+class Word2VecPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.Word2VecPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Word2VecPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setPredMethod(self, val):
+        return self._add_param('predMethod', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
+
